@@ -87,13 +87,13 @@ def {m}(self, new_val):
 	def schedule(self): schedulers.schedule(self) 
 
 	@property
-	def create_date(self): return self.history[0][0]
+	def create_date(self): return self.history[0][0] if self.history else None
 	@property
-	def seen_date(self): return self.history[-1][0]
+	def seen_date(self): return self.history[-1][0] if self.history else None
 	@property
-	def last_grade(self): return self.history[-1][2]
+	def last_grade(self): return self.history[-1][2] if self.history else None
 	@property
-	def last_interval(self): return self.history[-1][0] - self.history[-2][0]  
+	def last_interval(self): return self.history[-1][0] - self.history[-2][0] if len(self.history)>1 else None
 
 	@property
 	def new(self): return self.last_grade == 'create'
